<!-- 
ECM II Cipher machine simulator
Adapted from a java applet originally written by Richard J. Pekelney.

Author:	Stephen R. MacMinn, April 15, 2024

 * REVISION HISTORY:
 *
 *   Date   		Version By  	Purpose of Revision
 * -------- 		------- --- 	--------------------------------------
 * 8  Apr 2024		1.00	SRM		First Javascript release.
 * 17 Apr 2024		1.1		SRM		Upgraded to allow custom rotor sets.
 *
 -->
<head>
	<meta name="viewport" content="width=650, height=750, initial-scale=0.75">
	
    <title>ECM Simulator</title>
	<meta charset="utf-8" />

	<!-- CSS -->

	<link rel="stylesheet" href="css/milligram.min.css" />
	<link rel="stylesheet" href="css/ecm.css" />
	<link rel="stylesheet" href="css/slideout.css" />
	

	<!-- JavaScript -->

	<script src="js/csv-index.js"			defer></script>
	<script src="js/ECMStorageManager.js"	defer></script>
	<script src="js/Rotor.js"        		defer></script>
	<script src="js/CipherRotor.js"  		defer></script>
	<script src="js/ControlRotor.js" 		defer></script>
	<script src="js/IndexRotor.js"   		defer></script>
	<script src="js/RotorCage.js"    		defer></script>
	<script src="js/ECMapp.js"       		defer></script>
</head>

<body>

<div class="header"></div>
  <input type="checkbox" class="openSidebarMenu" id="openSidebarMenu">
  <label for="openSidebarMenu" class="sidebarIconToggle">
    <div class="spinner diagonal part-1"></div>
    <div class="spinner horizontal"></div>
    <div class="spinner diagonal part-2"></div>
  </label>

  
 <div id="sidebarMenu">
    <ul class="sidebarMenuInner">
      <li style="font-size: 12pt;"><a id='aboutDialogOpener'>About ECM Simulator</a></li>
      <li style="font-size: 14pt;">Simulator Options:</li>
 	  <li style="font-size: 12pt; color:gray;"><a id='uploadDialogOpener'>Upload New Rotor Set</a></li>
      <li style="font-size: 12pt; color:gray;"><a id="manageRotorSetsDialogOpener">Manage Rotor Sets</a></li> 
      <li style="font-size: 12pt; color:gray;"><a id='rotorOrderDialogOpener'>Change Rotor Order</a></li>
    </ul>
 </div>

<div id="ecmBody" class="container">
	<div class="row" style="margin-top:20px;">
	
<!-- Mode and Machine Type controls -->
		
		<div class="column column-20">
			<div>
				<label for="zeroSwitch" style="font-size: 10pt;">Zeroize			
					<select id='zeroSwitch' name="zeroize">
						<option value="Zeroize" >Zeroize </option>
						<option value="">						 </option>
						<option value="Operate" selected>Operate 		 </option>
					</select>
				</label>
			</div>
			
			<div style="padding-top: 20px;">
				<label for="machSwitch" style="font-size: 10pt;">Machine Type			
					<select id='machSwitch' name="machine">
						<option value="CSP 889" selected>CSP 889 </option>
						<option value="">						 </option>
						<option value="CSP 2900">CSP 2900 		 </option>
					</select>
				</label>
			</div>		
		</div>
		
<!-- Three rotor bank displays -->

		<div class="column column-20" style="padding:0;">
			<div>
				<label for="cipherDisp" style="font-size: 10pt; ">Cipher Rotor
				<input id="cipherDisp" class="rotorDisplay" name="cipherDisp" type="text" maxlength=5>
				</label>
			</div>
			<div>
				<label for="controlDisp" style="font-size: 10pt; ">Control Rotor
				<input id="controlDisp" class="rotorDisplay" name="controlDisp" type="text" maxlength=5>
				</label>
			</div>
			<div>
				<label for="indexDisp" style="font-size: 10pt; ">Index Rotor
				<input id="indexDisp" class="rotorDisplay" name="indexDisp" type="text" maxlength=5>
				</label>
			</div>
		</div>
		
<!-- Master switch and counter with clear button  -->

		<div class="column column-20">
			<div>
				<label for="masterSwitch" style="font-size: 10pt; ">Function
				<select id="masterSwitch" name="master" style="font-size:8pt;">
					<option value="O" >O: Off </option>
					<option value="P">P: Print </option>
					<option value="R">R: Reset </option>
					<option value="E" selected>E: Encrypt </option>
					<option value="D">D: Decrypt </option>
				</select>
				</label>
			</div>
				
			<div style="display:flex;">
				<label for="countDisp" style="display:flex; font-size: 10pt; margin:auto;">Counter
 				<input id="countDisp" class="rotorDisplay" style="margin:auto; display:flex; width: 6rem;">
				<button id="clearCounter" class="clrButton" name="clearCounter" style="margin:auto;">CLEAR</button>
				</label>
			</div>

		
		</div>
 		
<!-- Paper tape -->
		
		<div class="column column-40">
			<span style="font-size: 10pt; color:white;">Paper Tape:</span>

			<div id="paperTape" class="text" style="margin-left: 5px; margin-bottom:5px; margin-right: 5px;" ></div>
			<input id="copyPaperTape" class="copyTape" type="image" src="img/copyIcon-small.png" alt="copy"><br />
		<!-- Tape tear-off button -->

			<button id="tearTape" class="clrButton" style="padding-left: 5px; padding-right:5px; width:fit-content;">Tear off tape</button>		

		</div>
	</div>

	<!-- Keyboard Input Display -->

	<div class="row" style="margin-top:10px;">
		<div class="column column-100">
			<div>
				<span style="font-size: 10pt; color:white;">Keyboard Display:</span>
			</div>
			<div style="margin-left: auto;margin-right: auto;height: 50px;align-items: center;display: flex;">
				<div style="margin: 0 auto;">
				<div  id="keyboardDisplay" class="text" style="margin-bottom:5px;width:400px;margin-right: 10px;" ></div>
 				<input id="copyKeyboardDisplay"  class="copyTape" type="image" src="img/copyIcon-small.png" alt="copy">
				<button id="clearKeyboardDisplay" class="clrButton"style="margin-left:10px; padding-left: 5px; padding-right:5px; width:fit-content;" >
				Clear
				</button>
				</div>
			</div>
		</div>
	</div>
	
	<!-- Keyboard row 1 -->

	<div class="row" style="margin-top:10px;">
			
		<div class="keys column column-10">
			<div class="img-container">
				<button id="1_key" class="vKeyboard" name="1">1</button>
			</div>
		</div>	
		
		<div class="keys column column-10">
			<div class="img-container">
				<button id="2_key"  class="vKeyboard" name="2">2</button>
			</div>
		</div>	

		<div class="keys column column-10">
			<div class="img-container">
				<button id="3_key"  class="vKeyboard" name="3">3</button>
			</div>
		</div>	

		<div class="column column-10">
			<div class="img-container">
				<button id="4_key"  class="vKeyboard" name="4">4</button>
			</div>
		</div>
			
		<div class="column column-10">
			<div class="img-container">
				<button id="5_key"  class="vKeyboard" name="5">5</button>
			</div>
		</div>
			
		<div class="column column-10">
			<div class="img-container">
				<button id="6_key"  class="vKeyboard" name="6">6</button>
			</div>
		</div>
			
		<div class="column column-10">
			<div class="img-container">
				<button id="7_key"  class="vKeyboard" name="7">7</button>
			</div>
		</div>
			
		<div class="column column-10">
			<div class="img-container">
				<button id="8_key"  class="vKeyboard" name="8">8</button>
			</div>
		</div>	
		<div class="column column-10">
			<div class="img-container">
				<button id="9_key"  class="vKeyboard" name="9">9</button>
			</div>
		</div>	
		<div class="column column-10">
			<div class="img-container">
				<button id="0_key"  class="vKeyboard" name="0">0</button>
			</div>
		</div>	

	</div>
	
	
		<!-- Keyboard row 2 -->
	<div class="row" style="margin-top:10px;">
	
		<div class="column column-10">
			<button class="vKeyboard" id="Q_key" name="Q">Q</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="W_key" name="W">W</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="E_key" name="E">E</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="R_key" name="R">R</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="T_key" name="T">T</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="Y_key" name="Y">Y</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="U_key" name="U">U</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="I_key" name="I">I</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="O_key" name="O">O</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="P_key" name="P">P</button>
		</div>	

	</div>
	
	
		<!-- Keyboard row 3 -->
	<div class="row" style="margin-top:10px;">
	
		<div class="column column-10">
			<button class="vKeyboard" id="A_key" name="A">A</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="S_key" name="S">S</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="D_key" name="D">D</button>
		</div>	

		
		<div class="column column-10">
			<button class="vKeyboard" id="F_key" name="F">F</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="G_key" name="G">G</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="H_key" name="H">H</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="J_key" name="J">J</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="K_key" name="K">K</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="L_key" name="L">L</button>
		</div>	

		<div class="column column-10">
			<!-- The RPT key is a future feature -->
			<button class="vKeyboard" id="RPT_key" name="RPT" style="font-size:16px;"disabled>RPT</button>
		</div>	

	</div>
	
	
		<!-- Keyboard row 4 -->
	<div class="row" style="margin-top:10px;">
	
		<div class="column column-10">
			<!-- 
				The unlabeled key on the left has no event handler.  This key does not
				move on the real machine.
			--> 
			<button class="vKeyboard" id="no_key" name="no_key" disabled></button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="Z_key" name="Z">Z</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="X_key" name="X">X</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="C_key" name="C">C</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="V_key" name="V">V</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="B_key" name="B">B</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="N_key" name="N">N</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="M_key" name="M">M</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="dash_key" name="-">-</button>
		</div>	

		<div class="column column-10">
			<button class="vKeyboard" id="Blank_key" name="BLANK" style="font-size: 14px;">Blank</button>
		</div>	

	</div>
	
	<div class="row">

		<!-- Keyboard Space bar row -->
		<div class="column column-35"></div>
		<div class="column column-30">
			<button class="vKeyboard" style="width: 200px; height: 40px; border-radius: 20px;"id="spaceBar" name="SPACE">Space Bar</button>
		</div>
		<div class="column column-35"></div>
	</div>
</div>
</body>
<!-- 
<script>
	if('serviceWorker' in navigator) {
	  navigator.serviceWorker.register('/ecm/serviceWorker.js', { scope: '/ecm/' });
	}
</script>
 -->
</html>
