<?php
/** Rotor Set Generator
 *  Generate a set of 10 rotors for the ECM Encryption Machine Simulator
 *
 *  Each rotor consists of a random, non-repeating list of 26 letters.
 *  The output is written to "rotors.csv" in the same folder as the script.
 *
 *  This program uses PHP's rand() function, which is not random enough to be
 *  cryptographically secure, but it works for this demonstration purpose.
 *
 *  Author:  Stephen R. MacMinn, 2024-04-12
 *
 *
 */

define("LETTERS", ['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M',
                   'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z']);

$filename = "rotors.csv";
$handle = fopen($filename, "w");

/* seed the random number generator */

srand();
for($i=0; $i<10; $i++) {
   
    $rotor = generateRotor();
    fputcsv($handle, $rotor);
}

fclose($handle);
echo "Finished.  Output is in $filename.\n";

/** generateRotor
 *  Generate a rotor, which is an array of 26 distinct letters.
 *  generateRotor fills an array, $foundList, with the alphabet.  It then
 *  generates random lettes and checks whether they exist in $foundList.
 *  If so, the letter is added to the output array and deleted from $foundList.
 *  If not, the letter is skipped.
 *  When $foundList is empty, we're done.
 *
 * @return array    $rotor  Rotor array.
 */
function generateRotor() {
    $foundList = LETTERS;
    $count = 0;
    while(!empty($foundList)) {
        $char = rand(0,25);
        if(key_exists($char, $foundList)) {
            $rotor[$count++] = LETTERS[$char];
            if($count == 26) break;
            unset($foundList[$char]);
        }
    }
    return $rotor;
}

