/***********************************************************************
 * CipherRotor object extends Rotor
 * Copyright (C) 1996, by Richard Pekelney
 * All Rights Reserved
 *
 * SUMMARY:
 * This object contains a cipher rotor.  Cipher rotors are read from left to
 * right during encrypt and right to left during decrypt.  Since rotor wirings
 * supplied in a table of left to right wirings.  The object keeps a left to right
 * and a right to left version of the table.
 *
 * REVISION HISTORY:
 *
 *   Date   	Version By  	Purpose of Revision
 * -------- 	------- --- 	--------------------------------------
 * 8 Oct 96     1.00    RSP 	First release.
 * 8 Apr 2024	1.00	SRM		First Javascript release.
 *      
 *      
 ***********************************************************************/
class CipherRotor extends Rotor {
 //   cipherRotor = new Array(2)(26);

    constructor(wiringNum) {    // Constructor for Cipher Rotors.
		super();
		this.cipherRotor = [...Array(2)].map(e => Array(26));
		
        for(let i = 0 ; i < 26 ; i++) {
            this.cipherRotor[Rotor.LEFT][i] = Rotor.WIRING[wiringNum][i].charCodeAt(0) - 'A'.charCodeAt(0);
            this.cipherRotor[Rotor.RIGHT][this.cipherRotor[Rotor.LEFT][i]] = i;
        }
            
        super.reversed = false;
        this.pos = 0;
        return;
    }
        

/***********************************************************************
 * cipherEncPath() - Encrypt path through a rotor.
 * Copyright (C) 1996, by Richard Pekelney
 * All Rights Reserved
 *
 * SUMMARY:
 * Encrypt path through a cipher rotor is from left to right, except for reversed 
 * rotors.
 *
 * REVISION HISTORY:
 *
 *   Date   Version By  Purpose of Revision
 * -------- ------- --- --------------------------------------
 * 8 Oct 96     1.00    RSP First release.
 *      
 ***********************************************************************/
    cipherEncPath(inx) {
        var out;

		let x = this.pos;
		let y = this.pos;
		
        if (super.reversed) {
            out = (this.pos - this.cipherRotor[Rotor.RIGHT][(this.pos - inx + 26) % 26] + 26) % 26;
            }
        else {
            out = (this.cipherRotor[Rotor.LEFT][(inx + this.pos) % 26] - this.pos + 26) % 26;
            }
            
        return(out);
        }

/***********************************************************************
 * cipherDecPath() - Decrypt path through a rotor.
 * Copyright (C) 1996, by Richard Pekelney
 * All Rights Reserved
 *
 * SUMMARY:
 * Decrypt path through a cipher rotor is from right to left, except for reversed 
 * rotors.
 *
 * REVISION HISTORY:
 *
 *   Date   	Version By  	Purpose of Revision
 * -------- 	------- --- 	--------------------------------------
 * 8 Oct 96     1.00    RSP 	First release.
 * 8 Apr 2024	1.00	SRM		First Javascript release.
 *      
 ***********************************************************************/
    cipherDecPath(inx) {
        var out;

        if (super.reversed) {
            out = (this.pos - this.cipherRotor[Rotor.LEFT][(this.pos - inx + 26) % 26] + 26) % 26;
            }
        else {
            out = (this.cipherRotor[Rotor.RIGHT][(inx + this.pos) % 26] - this.pos + 26) % 26;
            }
            
        return(out);
        }

    } // end of CipherRotor
