/***********************************************************************
 * ControlRotor object extends Rotor
 * Copyright (C) 1996, by Richard Pekelney
 *
 * All Rights Reserved
 *
 * Translated to javascript by Stephen R. MacMinn
 * Javascript code Copyright (C) 2024, by Stephen R. MacMinn
 * 
 *
 * SUMMARY:
 * This object contains a control rotor.  Control rotors are always read from right
 * to left, except when reversed.  The object keeps a left to right version of the
 * wiring table to handle reversed rotors.
 *
 * REVISION HISTORY:
 *
 *   Date   	Version By  	Purpose of Revision
 * -------- 	------- --- 	--------------------------------------
 * 8 Oct 96     1.00    RSP 	First release.
 * 8 Apr 2024	1.00	SRM		First Javascript release.
 *      
 ***********************************************************************/
class ControlRotor extends Rotor {
//    controlRotor = new Array(2)(26);
	
    constructor(wiringNum) {   // Constructor for Control Rotors.
		super();
		this.controlRotor = [...Array(2)].map(e => Array(26));

        for(let i = 0 ; i < 26 ; i++) {
            this.controlRotor[Rotor.LEFT][i] = Rotor.WIRING[wiringNum][i].charCodeAt(0) - 'A'.charCodeAt(0);
            this.controlRotor[Rotor.RIGHT][this.controlRotor[Rotor.LEFT][i]] = i;
        }
            
        super.reversed = false;
        return;
    }

/***********************************************************************
 * controlPath() passes a current though a control rotor.
 * Copyright (C) 1996, by Richard Pekelney
 * All Rights Reserved
 *
 * SUMMARY:
 * controlPath() passes a current though a rotor. Control rotor pos is the clockwise
 * rotation from zero on top.  A reversed rotor can be thought of as an upside down,
 * (i.e. counter clockwise) and backwards (i.e. left to right) normal rotor.
 * The control rotors are always read from right to left, except for reversed rotors.
 *
 * REVISION HISTORY:
 *
 *   Date   	Version By  	Purpose of Revision
 * -------- 	------- --- 	--------------------------------------
 * 8 Oct 96     1.00    RSP 	First release.
 * 8 Apr 2024	1.00	SRM		First Javascript release.
 *      
 ***********************************************************************/
    controlPath(inx){
        var out;
 
        // Adding 26 to any value that might go negative prevents a negative value that might
        // cause a divide error during the mod (%) 26 operation.
        
        if (super.reversed) {
            out = (this.pos - this.controlRotor[Rotor.LEFT][(this.pos - inx + 26) % 26] + 26) % 26;
        } else {
            out = (this.controlRotor[Rotor.RIGHT][(inx + this.pos) % 26] - this.pos + 26) % 26;
        }
        
        return(out);
    }
        
} // end of ControlRotor class
