/** ECMStorageManager - Manage stored rotor sets and parameters.
 *  Two types of objects are stored: rotor sets, 
 *  and rotor starting positions (rotor start sets).
 * 
 *  The list of rotor sets is stored under the key ECMStorageManager.ROTOR_SETS_INDEX
 *  The list of rotor start positions is stored under the key ECMStorageManager.ROTOR_START_POS
 * 
 * REVISION HISTORY:
 *
 *   Date   	Version 	By  	Purpose of Revision
 * -------- 	------- 	--- 	--------------------------------------
 * 17 Apr 2024	1.10		SRM		First release
 * 
 * 
 */


 class ECMStorageManager {
	
	static ROTOR_SETS_INDEX = 'rotor_sets';
	static ROTOR_START_POS = 'rotor_start_sets';

		
	/* generate a list of the stored rotor sets, or an empty array. */
	
	listRotorSets() {
		let index = localStorage.getItem(ECMStorageManager.ROTOR_SETS_INDEX) ?
		JSON.parse(localStorage.getItem(ECMStorageManager.ROTOR_SETS_INDEX)) : [];
		return index;
	}
	
	/* generate a list of the stored rotor starting position sets, or an empty array. */

	listRotorPositionSets() {
		let index = localStorage.getItem(ECMStorageManager.ROTOR_POS_INDEX) ?
		JSON.parse(localStorage.getItem(ECMStorageManager.ROTOR_POS_INDEX)) : [];
		return index;
	}
	
	/* add a named rotor set to the list of rotor sets. */
	
	addRotorSet(name, set) {
		let items = localStorage.getItem(name);
		if(items) {
			return [false, "Rotor set " + name + " already exists."];
		}
		
		if(!name) {
			return [false, "Rotor set name cannot be empty"];
		} else if(name === ECMStorageManager.ROTOR_SETS_INDEX) {
			return [false, "The name " + name + " is reserved."];			
		}
		localStorage.setItem(name, JSON.stringify(set));
		
		/* Record this set in the list of names. */
		
		let index = localStorage.getItem(ECMStorageManager.ROTOR_SETS_INDEX) ?
		JSON.parse(localStorage.getItem(ECMStorageManager.ROTOR_SETS_INDEX)) : [];
		index.push(name);
		localStorage.setItem(ECMStorageManager.ROTOR_SETS_INDEX, JSON.stringify(index));
		return [true, "Rotor set " + name + " added to local storage"];

	}
	
	getRotorSet(name) {
		let rotorSet_json = localStorage.getItem(name);
		
		if(!rotorSet_json) {
			return [false, "Rotor set " + name + " not found."];		
		}

		/* If it exists, remove it and remove its name from the index. */
		
		let rotorSet = JSON.parse(rotorSet_json);
		return rotorSet;
	}
	
	addRotorPositionSet() {
		/* TBD */
	}
	
	deleteRotorSet(name) {
		if(!name) {
			return [false, "Rotor set name cannot be empty"];
		}
		
		let items = localStorage.getItem(name);
		
		if(!items) {
			return [false, "Rotor set " + name + " not found."];		
		}

		/* If it exists, remove it and remove its name from the index. */
		
		localStorage.removeItem(name);		
		let indexStr= localStorage.getItem(ECMStorageManager.ROTOR_SETS_INDEX);
		let indexArray = JSON.parse(indexStr);
		let n = indexArray.indexOf(name);
		indexArray.splice(n, 1);
		indexStr= JSON.stringify(indexArray);
		localStorage.setItem(ECMStorageManager.ROTOR_SETS_INDEX, indexStr);
		return [true, "Rotor set " + name + " deleted."];			
	}
	
	deleteRotorPositionSet() {
		/* TBD */
	}
 }