/***********************************************************************
 * IndexRotor object extends Rotor
 * Copyright (C) 1996, by Richard Pekelney
 * 
 * All Rights Reserved
 * 
 * Translated to javascript by Stephen R. MacMinn
 * Javascript code Copyright (C) 2024, by Stephen R. MacMinn
 * 
 *
 * SUMMARY:
 * This object contains an index rotor.  Index rotors are always read from left
 * to right, except when reversed.  The object keeps a right to left version of the
 * wiring table to handle reversed rotors.
 *
 * REVISION HISTORY:
 *
 *   Date   	Version By  	Purpose of Revision
 * -------- 	------- --- 	--------------------------------------
 * 8 Oct 96     1.00    RSP 	First release.
 * 8 Apr 2024	1.00	SRM		First Javascript release.
 *      
 ***********************************************************************/
class IndexRotor extends Rotor {
//    indexRotor = new Array[2][10];

    constructor(wiringNum) { // Constructor for Index Rotors.
		super();
		this.indexRotor = [...Array(2)].map(e => Array(10));


        for(let i = 0 ; i < 10 ; i++) {
            this.indexRotor[Rotor.LEFT][i] = Rotor.INDEXWIRING[wiringNum][i];
            this.indexRotor[Rotor.RIGHT][this.indexRotor[Rotor.LEFT][i]] = i;
            }
            
        super.reversed = false;
        return;
        }  

/***********************************************************************
 * indexPath() passes a current though an index rotor..
 * Copyright (C) 1996, by Richard Pekelney
 * All Rights Reserved
 *
 * SUMMARY:
 * indexPath() passes a current though an index rotor.  Index rotor pos is the counter
 * clockwise rotation from zero on top.  A reversed rotor can be thought of as
 * an upside down, (i.e. clockwise) and backwards (i.e. right to left) normal rotor.
 * The index rotors are always read from left to right, except for reversed rotors.
 *
 * REVISION HISTORY:
 *
 *   Date   	Version By  	Purpose of Revision
 * -------- 	------- --- 	--------------------------------------
 * 8 Oct 96     1.00    RSP 	First release.
 * 8 Apr 2024	1.00	SRM		First Javascript release.
 *      
 ***********************************************************************/
    indexPath(inx){
        var out;

        // Adding 10 to any value that might go negative prevents a negative value that might
        // cause a divide error during the mod (%) 10 operation.
        
        if (super.reversed) {     // This is a reversed rotor.
            out = (this.pos - this.indexRotor[Rotor.RIGHT][(this.pos - inx + 10) % 10] + 10) % 10;
            }
        else {              // This is a normal rotor.
            out = (this.indexRotor[Rotor.LEFT][(inx + this.pos) % 10] - this.pos + 10) % 10;
            }
        
        return(out);    
        }
        
    } // end of IndexRotor class